@@ -316,7 +316,6 @@ class Index():
         """
         if parameters is None:
             parameters = {}
-
         return self.http.get(
             f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}?{urllib.parse.urlencode(parameters)}'
         )
@@ -346,11 +345,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        if primary_key is None:
-            url = f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}'
-        else:
-            primary_key = urllib.parse.urlencode({'primaryKey': primary_key})
-            url = f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}?{primary_key}'
+        url = self._build_url(primary_key)
         return self.http.post(url, documents)
 
     def add_documents_in_batches(
@@ -391,6 +386,118 @@ class Index():
 
         return update_ids
 
+    def add_documents_json(
+        self,
+        str_documents: str,
+        primary_key: Optional[str] = None,
+    ) -> Dict[str, int]:
+        """Add string documents from JSON file to the index.
+
+        Parameters
+        ----------
+        str_documents:
+            String of document from a JSON file.
+        primary_key (optional):
+            The primary-key used in index. Ignored if already set up.
+
+        Returns
+        -------
+        update:
+            Dictionary containing an update id to track the action:
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return self.add_documents_raw(str_documents, primary_key, 'application/json')
+
+    def add_documents_csv(
+        self,
+        str_documents: str,
+        primary_key: Optional[str] = None,
+    ) -> Dict[str, int]:
+        """Add string documents from a CSV file to the index.
+
+        Parameters
+        ----------
+        str_documents:
+            String of document from a CSV file.
+        primary_key (optional):
+            The primary-key used in index. Ignored if already set up.
+
+        Returns
+        -------
+        update:
+            Dictionary containing an update id to track the action:
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return self.add_documents_raw(str_documents, primary_key, 'text/csv')
+
+    def add_documents_ndjson(
+        self,
+        str_documents: str,
+        primary_key: Optional[str] = None,
+    ) -> Dict[str, int]:
+        """Add string documents from a NDJSON file to the index.
+
+        Parameters
+        ----------
+        str_documents:
+            String of document from a NDJSON file.
+        primary_key (optional):
+            The primary-key used in index. Ignored if already set up.
+
+        Returns
+        -------
+        update:
+            Dictionary containing an update id to track the action:
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return self.add_documents_raw(str_documents, primary_key, 'application/x-ndjson')
+
+    def add_documents_raw(
+        self,
+        str_documents: str,
+        primary_key: Optional[str] = None,
+        content_type: Optional[str] = None,
+    ) -> Dict[str, int]:
+        """Add string documents to the index.
+
+        Parameters
+        ----------
+        str_documents:
+            String of document.
+        primary_key (optional):
+            The primary-key used in index. Ignored if already set up.
+        type:
+            The type of document. Type available: 'csv', 'json', 'jsonl'
+
+        Returns
+        -------
+        update:
+            Dictionary containing an update id to track the action:
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        url = self._build_url(primary_key)
+        return self.http.post(url, str_documents, content_type)
+
     def update_documents(
         self,
         documents: List[Dict[str, Any]],
@@ -416,11 +523,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        if primary_key is None:
-            url = f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}'
-        else:
-            primary_key = urllib.parse.urlencode({'primaryKey': primary_key})
-            url = f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}?{primary_key}'
+        url = self._build_url(primary_key)
         return self.http.put(url, documents)
 
     def update_documents_in_batches(
@@ -1036,6 +1139,70 @@ class Index():
             self.__settings_url_for(self.config.paths.filterable_attributes),
         )
 
+
+    # SORTABLE ATTRIBUTES SUB-ROUTES
+
+    def get_sortable_attributes(self) -> List[str]:
+        """
+        Get sortable attributes of the index.
+
+        Returns
+        -------
+        settings:
+            List containing the sortable attributes of the index
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return self.http.get(
+            self.__settings_url_for(self.config.paths.sortable_attributes)
+        )
+
+    def update_sortable_attributes(self, body: List[str]) -> Dict[str, int]:
+        """
+        Update sortable attributes of the index.
+
+        Parameters
+        ----------
+        body:
+            List containing the sortable attributes.
+
+        Returns
+        -------
+        update:
+            Dictionary containing an update id to track the action:
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return self.http.post(
+            self.__settings_url_for(self.config.paths.sortable_attributes),
+            body
+        )
+
+    def reset_sortable_attributes(self) -> Dict[str, int]:
+        """Reset sortable attributes of the index to default values.
+
+        Returns
+        -------
+        update:
+            Dictionary containing an update id to track the action:
+            https://docs.meilisearch.com/reference/api/updates.html#get-an-update-status
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why MeiliSearch can't process your request. MeiliSearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return self.http.delete(
+            self.__settings_url_for(self.config.paths.sortable_attributes),
+        )
+
     @staticmethod
     def _batch(
         documents: List[Dict[str, Any]], batch_size: int
@@ -1070,3 +1237,12 @@ class Index():
 
     def __settings_url_for(self, sub_route: str) -> str:
         return f'{self.config.paths.index}/{self.uid}/{self.config.paths.setting}/{sub_route}'
+
+    def _build_url(
+        self,
+        primary_key: Optional[str] = None,
+    ) -> str:
+        if primary_key is None:
+            return f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}'
+        primary_key = urllib.parse.urlencode({'primaryKey': primary_key})
+        return f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}?{primary_key}'
